==> com.liferay.dynamic.data.mapping.form.renderer-4.0.40.jar: META-INF/resources/js/components/FormRenderer/FormRenderer.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.40/js/components/FormRenderer/FormRenderer.es", ['module', 'exports', 'require', '../../containers/Pagination/Pagination.es', '../../containers/PaginationControls/PaginationControls.es', '../../containers/Tabs/Tabs.es', '../../containers/Wizard/Wizard.es', '../PageRenderer/PageRenderer.es', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './FormRenderer.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  require("../../containers/Pagination/Pagination.es");

  require("../../containers/PaginationControls/PaginationControls.es");

  require("../../containers/Tabs/Tabs.es");

  require("../../containers/Wizard/Wizard.es");

  require("../PageRenderer/PageRenderer.es");

  require("frontend-taglib-clay$clay-button");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _FormRenderer = _interopRequireDefault(require("./FormRenderer.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FormRenderer.
   * @extends Component
   */
  var FormRenderer =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FormRenderer, _Component);

    function FormRenderer() {
      _classCallCheck(this, FormRenderer);

      return _possibleConstructorReturn(this, _getPrototypeOf(FormRenderer).apply(this, arguments));
    }

    _createClass(FormRenderer, [{
      key: "_defaultLanguageIdValueFn",
      value: function _defaultLanguageIdValueFn() {
        return themeDisplay.getLanguageId();
      }
    }, {
      key: "_editingLanguageIdValueFn",
      value: function _editingLanguageIdValueFn() {
        var defaultLanguageId = this.defaultLanguageId;
        return defaultLanguageId;
      }
    }, {
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        this.emit('fieldBlurred', event);
      }
    }, {
      key: "_handleFieldClicked",
      value: function _handleFieldClicked(index) {
        this.emit('fieldClicked', index);
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        this.emit('fieldEdited', event);
      }
    }, {
      key: "_handleFieldFocused",
      value: function _handleFieldFocused(event) {
        this.emit('fieldFocused', event);
      }
    }]);

    return FormRenderer;
  }(_metalComponent["default"]);

  FormRenderer.STATE = {
    /**
     * @default
     * @instance
     * @memberof FormRenderer
     * @type {?number}
     */
    activePage: _metalState.Config.number().value(0),

    /**
     * @default undefined
     * @memberof FormRenderer
     * @type {string}
     * @required
     */
    defaultLanguageId: _metalState.Config.string().valueFn('_defaultLanguageIdValueFn'),

    /**
     * @default false
     * @instance
     * @memberof FormRenderer
     * @type {?bool}
     */
    editable: _metalState.Config.bool().value(false),

    /**
     * @default undefined
     * @memberof FormRenderer
     * @type {string}
     * @required
     */
    editingLanguageId: _metalState.Config.string().valueFn('_editingLanguageIdValueFn'),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    pages: _metalState.Config.array().value([]),

    /**
     * @instance
     * @memberof FormRenderer
     * @type {string}
     */
    portletNamespace: _metalState.Config.string().required(),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    rules: _metalState.Config.array().value([]),

    /**
     * @default undefined
     * @instance
     * @memberof FormRenderer
     * @type {!string}
     */
    spritemap: _metalState.Config.string().required()
  };

  _metalSoy["default"].register(FormRenderer, _FormRenderer["default"]);

  var _default = FormRenderer;
  exports["default"] = _default;
  //# sourceMappingURL=FormRenderer.es.js.map
});
//# sourceMappingURL=FormRenderer.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-4.0.53.jar: META-INF/resources/js/components/FormRenderer/FormRenderer.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.53/js/components/FormRenderer/FormRenderer.es", ['module', 'exports', 'require', '../../containers/Pagination/Pagination.es', '../../containers/PaginationControls/PaginationControls.es', '../../containers/Tabs/Tabs.es', '../../containers/Wizard/Wizard.es', '../PageRenderer/PageRenderer.es', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './FormRenderer.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  require("../../containers/Pagination/Pagination.es");

  require("../../containers/PaginationControls/PaginationControls.es");

  require("../../containers/Tabs/Tabs.es");

  require("../../containers/Wizard/Wizard.es");

  require("../PageRenderer/PageRenderer.es");

  require("frontend-taglib-clay$clay-button");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _FormRenderer = _interopRequireDefault(require("./FormRenderer.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FormRenderer.
   * @extends Component
   */
  var FormRenderer = /*#__PURE__*/function (_Component) {
    _inherits(FormRenderer, _Component);

    function FormRenderer() {
      _classCallCheck(this, FormRenderer);

      return _possibleConstructorReturn(this, _getPrototypeOf(FormRenderer).apply(this, arguments));
    }

    _createClass(FormRenderer, [{
      key: "attached",
      value: function attached() {
        Liferay.fire("".concat(this.portletNamespace, "simplecaptcha_attachEvent"));
      }
    }, {
      key: "_defaultLanguageIdValueFn",
      value: function _defaultLanguageIdValueFn() {
        return themeDisplay.getLanguageId();
      }
    }, {
      key: "_editingLanguageIdValueFn",
      value: function _editingLanguageIdValueFn() {
        var defaultLanguageId = this.defaultLanguageId;
        return defaultLanguageId;
      }
    }, {
      key: "_getDisplayableFn",
      value: function _getDisplayableFn() {
        var containerId = this.containerId,
            readOnly = this.readOnly,
            viewMode = this.viewMode;
        return readOnly || !viewMode || document.getElementById(containerId) !== null;
      }
    }, {
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        this.emit('fieldBlurred', event);
      }
    }, {
      key: "_handleFieldClicked",
      value: function _handleFieldClicked(index) {
        this.emit('fieldClicked', index);
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        this.emit('fieldEdited', event);
      }
    }, {
      key: "_handleFieldFocused",
      value: function _handleFieldFocused(event) {
        this.emit('fieldFocused', event);
      }
    }]);

    return FormRenderer;
  }(_metalComponent["default"]);

  FormRenderer.STATE = {
    /**
     * @default
     * @instance
     * @memberof FormRenderer
     * @type {?number}
     */
    activePage: _metalState.Config.number().value(0),

    /**
     * @default undefined
     * @memberof FormRenderer
     * @type {string}
     * @required
     */
    containerId: _metalState.Config.string().value(''),

    /**
     * @default undefined
     * @memberof FormRenderer
     * @type {string}
     * @required
     */
    defaultLanguageId: _metalState.Config.string().valueFn('_defaultLanguageIdValueFn'),

    /**
     * @default false
     * @instance
     * @memberof FormRenderer
     * @type {?bool}
     */
    displayable: _metalState.Config.bool().valueFn('_getDisplayableFn'),

    /**
     * @default false
     * @instance
     * @memberof FormRenderer
     * @type {?bool}
     */
    editable: _metalState.Config.bool().value(false),

    /**
     * @default undefined
     * @memberof FormRenderer
     * @type {string}
     * @required
     */
    editingLanguageId: _metalState.Config.string().valueFn('_editingLanguageIdValueFn'),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    pages: _metalState.Config.array().value([]),

    /**
     * @instance
     * @memberof FormRenderer
     * @type {string}
     */
    portletNamespace: _metalState.Config.string().required(),

    /**
     * @default false
     * @instance
     * @memberof FormRenderer
     * @type {?bool}
     */
    readOnly: _metalState.Config.bool().value(false),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    rules: _metalState.Config.array().value([]),

    /**
     * @default undefined
     * @instance
     * @memberof FormRenderer
     * @type {!string}
     */
    spritemap: _metalState.Config.string().required(),

    /**
     * @default false
     * @instance
     * @memberof FormRenderer
     * @type {?bool}
     */
    viewMode: _metalState.Config.bool().value(false)
  };

  _metalSoy["default"].register(FormRenderer, _FormRenderer["default"]);

  var _default = FormRenderer;
  exports["default"] = _default;
  //# sourceMappingURL=FormRenderer.es.js.map
});
//# sourceMappingURL=FormRenderer.es.js.map
